@@ -15,8 +15,8 @@ module ReverseMarkdown
       # Override #treat as proposed in https://github.com/xijo/reverse_markdown/pull/69
       def treat(node, state)
         case node.name
-        when 'code'
-          node.text
+        when 'code', 'text'
+          node.text.strip
         when 'br'
           "\n"
         else
